You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2010/03/16 01:20:00 UTC

svn commit: r923519 [1/2] - in /directory/apacheds/trunk: avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/ avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/ core-api/src/main/java/org/apache/director...

Author: elecharny
Date: Tue Mar 16 00:19:58 2010
New Revision: 923519

URL: http://svn.apache.org/viewvc?rev=923519&view=rev
Log:
Injected the new Exceptions

Modified:
    directory/apacheds/trunk/avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/AvlStore.java
    directory/apacheds/trunk/avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/AvlStoreTest.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/DescriptionParsers.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java
    directory/apacheds/trunk/core-entry/src/main/java/org/apache/directory/server/core/entry/ServerEntryUtils.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/authz/SearchAuthorizationIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/changelog/DefaultChangeLogIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/exception/ExceptionServiceIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/DestroyContextIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/MixedCaseITest.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/bind/SimpleBindIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyAddIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyDelIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaAttributeTypeHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaComparatorHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaMatchingRuleHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaNormalizerHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaObjectClassHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaSchemaHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaSyntaxCheckerHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/MetaSyntaxHandlerIT.java
    directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/schema/SubschemaSubentryIT.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/authn/AuthenticationInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/collective/CollectiveAttributesSchemaChecker.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/exception/ExceptionInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/partition/DefaultPartitionNexus.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/schema/SchemaInterceptor.java
    directory/apacheds/trunk/core/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java

Modified: directory/apacheds/trunk/avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/AvlStore.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/AvlStore.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/AvlStore.java (original)
+++ directory/apacheds/trunk/avl-partition/src/main/java/org/apache/directory/server/core/partition/avl/AvlStore.java Tue Mar 16 00:19:58 2010
@@ -50,7 +50,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.entry.Modification;
 import org.apache.directory.shared.ldap.entry.ModificationOperation;
 import org.apache.directory.shared.ldap.entry.Value;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.AVA;
@@ -182,7 +182,7 @@ public class AvlStore<E> implements Stor
         // don't keep going if we cannot find the parent Id
         if ( parentId == null )
         {
-            throw new LdapNameNotFoundException( I18n.err( I18n.ERR_216, parentDn ) );
+            throw new LdapNoSuchObjectException( I18n.err( I18n.ERR_216, parentDn ) );
         }
 
         EntryAttribute objectClass = entry.get( OBJECT_CLASS_AT );

Modified: directory/apacheds/trunk/avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/AvlStoreTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/AvlStoreTest.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/AvlStoreTest.java (original)
+++ directory/apacheds/trunk/avl-partition/src/test/java/org/apache/directory/server/core/partition/avl/AvlStoreTest.java Tue Mar 16 00:19:58 2010
@@ -54,7 +54,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.cursor.Cursor;
 import org.apache.directory.shared.ldap.entry.Modification;
 import org.apache.directory.shared.ldap.entry.ModificationOperation;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -795,7 +795,7 @@ public class AvlStoreTest
     }
 
 
-    @Test(expected = LdapNameNotFoundException.class)
+    @Test(expected = LdapNoSuchObjectException.class)
     public void testAddWithoutParentId() throws Exception
     {
         DN dn = new DN( "cn=Marting King,ou=Not Present,o=Good Times Co." );

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/DescriptionParsers.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/DescriptionParsers.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/DescriptionParsers.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/DescriptionParsers.java Tue Mar 16 00:19:58 2010
@@ -32,7 +32,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.entry.EntryAttribute;
 import org.apache.directory.shared.ldap.entry.Value;
 import org.apache.directory.shared.ldap.exception.LdapInvalidAttributeValueException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.schema.AttributeType;
 import org.apache.directory.shared.ldap.schema.DITContentRule;
@@ -245,35 +245,35 @@ public class DescriptionParsers
             // if the supertype is provided make sure it exists in some schema
             if ( ( attributeType.getSuperiorOid() != null ) && !schemaManager.getAttributeTypeRegistry().contains( attributeType.getSuperiorOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_409, attributeType.getSuperiorOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_409, attributeType.getSuperiorOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             // if the syntax is provided by the description make sure it exists in some schema
             if ( attributeType.getSyntaxOid() != null && !schemaManager.getLdapSyntaxRegistry().contains( attributeType.getSyntaxOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_410, attributeType.getSyntaxOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_410, attributeType.getSyntaxOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             // if the matchingRule is provided make sure it exists in some schema
             if ( attributeType.getEqualityOid() != null && !schemaManager.getMatchingRuleRegistry().contains( attributeType.getEqualityOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_411, attributeType.getEqualityOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_411, attributeType.getEqualityOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             // if the matchingRule is provided make sure it exists in some schema
             if ( attributeType.getOrderingOid() != null && !schemaManager.getMatchingRuleRegistry().contains( attributeType.getOrderingOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_412, attributeType.getOrderingOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_412, attributeType.getOrderingOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             // if the matchingRule is provided make sure it exists in some schema
             if ( attributeType.getSubstringOid() != null && !schemaManager.getMatchingRuleRegistry().contains( attributeType.getSubstringOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_413, attributeType.getSubstringOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_413, attributeType.getSubstringOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
@@ -284,7 +284,7 @@ public class DescriptionParsers
             {
                 if ( attributeType.getSuperiorOid() == null )
                 {
-                    throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_414 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
+                    throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_414 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
                 }
                 else
                 {
@@ -293,7 +293,7 @@ public class DescriptionParsers
 
                     if ( superType == null )
                     {
-                        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_415 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
+                        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_415 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
                     }
                 }
             }
@@ -304,7 +304,7 @@ public class DescriptionParsers
             // if a supertype exists then it must resolve a proper syntax somewhere in the hierarchy.
             if ( attributeType.getSyntaxOid() == null && attributeType.getSuperiorOid() == null )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_416 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_416 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             List<Throwable> errors = new ArrayList<Throwable>();
@@ -317,7 +317,7 @@ public class DescriptionParsers
             if ( ( attributeType.getExtensions() == null )
                 || ( attributeType.getExtensions().get( MetaSchemaConstants.X_SCHEMA ) == null ) )
             {
-                throw new LdapOperationNotSupportedException(
+                throw new LdapUnwillingToPerformException(
                     "Cannot permit the addition of an attributeType not associated with a schema ",
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
@@ -381,7 +381,7 @@ public class DescriptionParsers
 
                     if ( !schemaManager.getObjectClassRegistry().contains( superiorOid ) )
                     {
-                        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_418, superiorOid ),
+                        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_418, superiorOid ),
                             ResultCodeEnum.UNWILLING_TO_PERFORM );
                     }
                 }
@@ -394,7 +394,7 @@ public class DescriptionParsers
                 {
                     if ( !schemaManager.getAttributeTypeRegistry().contains( mayAttrOid ) )
                     {
-                        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_419, mayAttrOid ),
+                        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_419, mayAttrOid ),
                             ResultCodeEnum.UNWILLING_TO_PERFORM );
                     }
                 }
@@ -407,7 +407,7 @@ public class DescriptionParsers
                 {
                     if ( !schemaManager.getAttributeTypeRegistry().contains( mustAttrOid ) )
                     {
-                        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_420, mustAttrOid ),
+                        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_420, mustAttrOid ),
                             ResultCodeEnum.UNWILLING_TO_PERFORM );
                     }
                 }
@@ -504,7 +504,7 @@ public class DescriptionParsers
 
             if ( !schemaManager.getSyntaxCheckerRegistry().contains( ldapSyntax.getOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_423 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_423 ), ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             ldapSyntax.setHumanReadable( isHumanReadable( ldapSyntax ) );
@@ -553,7 +553,7 @@ public class DescriptionParsers
 
             if ( !schemaManager.getLdapSyntaxRegistry().contains( matchingRule.getSyntaxOid() ) )
             {
-                throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_425, matchingRule.getSyntaxOid() ),
+                throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_425, matchingRule.getSyntaxOid() ),
                     ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AbstractRegistrySynchronizer.java Tue Mar 16 00:19:58 2010
@@ -33,9 +33,9 @@ import org.apache.directory.server.i18n.
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
 import org.apache.directory.shared.ldap.entry.EntryAttribute;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.exception.LdapNamingException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
@@ -200,20 +200,20 @@ public abstract class AbstractRegistrySy
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_337 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_337 ), ResultCodeEnum.NAMING_VIOLATION );
         }
         
         RDN rdn = newParent.getRdn();
         
         if ( ! schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals( SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_338, objectType ), 
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_338, objectType ), 
                 ResultCodeEnum.NAMING_VIOLATION );
         }
         
         if ( ! ( ( String ) rdn.getNormValue() ).equalsIgnoreCase( OBJECT_TYPE_TO_PATH.get( objectType ) ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_339, objectType,  OBJECT_TYPE_TO_PATH.get( objectType ) ), 
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_339, objectType,  OBJECT_TYPE_TO_PATH.get( objectType ) ), 
                 ResultCodeEnum.NAMING_VIOLATION );
         }
     }
@@ -264,7 +264,7 @@ public abstract class AbstractRegistrySy
                 String msg = I18n.err( I18n.ERR_341, schemaObject.getName(), schemaName );
                 LOG.warn( msg );
             
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
             
             schemaObjects.add( schemaObjectWrapper );
@@ -275,7 +275,7 @@ public abstract class AbstractRegistrySy
             String msg = I18n.err( I18n.ERR_342, schemaObject.getName(), schemaName );
             LOG.warn( msg );
         
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
     }
 
@@ -299,7 +299,7 @@ public abstract class AbstractRegistrySy
                 String msg = I18n.err( I18n.ERR_343, schemaObject.getName(), schemaName );
                 LOG.warn( msg );
             
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
             
             schemaObjects.remove( schemaObjectWrapper );
@@ -310,7 +310,7 @@ public abstract class AbstractRegistrySy
             String msg = I18n.err( I18n.ERR_342, schemaObject.getName(), schemaName );
             LOG.warn( msg );
         
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
     }
 

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/AttributeTypeSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -25,7 +25,7 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -99,7 +99,7 @@ public class AttributeTypeSynchronizer e
                 // We have some error : reject the addition and get out
                 String msg = I18n.err( I18n.ERR_345, entry.getDn().getName(), StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -180,7 +180,7 @@ public class AttributeTypeSynchronizer e
                 String msg = I18n.err( I18n.ERR_346, entry.getDn().getName(), 
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -221,7 +221,7 @@ public class AttributeTypeSynchronizer e
             {
                 String msg = I18n.err( I18n.ERR_347, entry.getDn().getName(), newDn );
 
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             schemaManager.unregisterAttributeType( oldAt.getOid() );
@@ -254,14 +254,14 @@ public class AttributeTypeSynchronizer e
         {
             String msg = I18n.err( I18n.ERR_348, oldSchemaName );
             LOG.warn( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
         if ( !isSchemaLoaded( newSchemaName ) )
         {
             String msg = I18n.err( I18n.ERR_349, newSchemaName );
             LOG.warn( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
         deleteFromSchema( oldAt, oldSchemaName );
@@ -301,14 +301,14 @@ public class AttributeTypeSynchronizer e
         {
             String msg = "Cannot move a schemaObject from a not loaded schema " + oldSchemaName;
             LOG.warn( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
         if ( !isSchemaLoaded( newSchemaName ) )
         {
             String msg = I18n.err( I18n.ERR_349, newSchemaName );
             LOG.warn( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
         deleteFromSchema( oldAt, oldSchemaName );

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ComparatorSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -30,9 +30,9 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.exception.LdapNamingException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
@@ -135,7 +135,7 @@ public class ComparatorSynchronizer exte
                 String msg = I18n.err( I18n.ERR_350, entry.getDn().getName(), StringTools.listToString( 
                     schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -213,7 +213,7 @@ public class ComparatorSynchronizer exte
                 String msg = I18n.err( I18n.ERR_352, entry.getDn().getName(), StringTools.listToString( 
                     errors ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -232,7 +232,7 @@ public class ComparatorSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_353, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_353, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -272,7 +272,7 @@ public class ComparatorSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_353, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_353, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -305,7 +305,7 @@ public class ComparatorSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_354, oid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_354, oid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -374,7 +374,7 @@ public class ComparatorSynchronizer exte
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_357 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_357 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
@@ -383,12 +383,12 @@ public class ComparatorSynchronizer exte
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_358 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_358 ), ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( SchemaConstants.COMPARATORS_AT ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_359 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_359 ), ResultCodeEnum.NAMING_VIOLATION );
         }
     }
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/MatchingRuleSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -27,8 +27,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -131,7 +131,7 @@ public class MatchingRuleSynchronizer ex
                 String msg = I18n.err( I18n.ERR_360, entry.getDn().getName(), 
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -184,7 +184,7 @@ public class MatchingRuleSynchronizer ex
                 String msg = I18n.err( I18n.ERR_360, entry.getDn().getName(), 
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -292,7 +292,7 @@ public class MatchingRuleSynchronizer ex
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_361 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_361 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
@@ -301,13 +301,13 @@ public class MatchingRuleSynchronizer ex
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_362 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_362 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( SchemaConstants.MATCHING_RULES_AT ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_363 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_363 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
     }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/NormalizerSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -30,9 +30,9 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.exception.LdapNamingException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -132,7 +132,7 @@ public class NormalizerSynchronizer exte
                 String msg = I18n.err( I18n.ERR_364, entry.getDn().getName(), 
                     StringTools.listToString( errors ) );
                 LOG.info( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -145,7 +145,7 @@ public class NormalizerSynchronizer exte
                 String msg = I18n.err( I18n.ERR_365, entry.getDn().getName(),
                     StringTools.listToString( errors ) );
 
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             LOG.debug( "The normalizer {} cannot be added in schema {}", dn.getName(), schemaName );
@@ -177,7 +177,7 @@ public class NormalizerSynchronizer exte
             {
                 String msg = I18n.err( I18n.ERR_366, entry.getDn().getName(), getReferenced( normalizer ) );
                 LOG.warn( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             // As the normalizer has the same OID than its attached MR, it won't
@@ -207,7 +207,7 @@ public class NormalizerSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_367, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_367, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -244,7 +244,7 @@ public class NormalizerSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_367, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_367, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -274,7 +274,7 @@ public class NormalizerSynchronizer exte
 
         if ( schemaManager.getMatchingRuleRegistry().contains( oid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_368, oid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_368, oid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -319,7 +319,7 @@ public class NormalizerSynchronizer exte
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_370 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_370 ), ResultCodeEnum.NAMING_VIOLATION );
         }
 
         RDN rdn = newParent.getRdn();
@@ -327,12 +327,12 @@ public class NormalizerSynchronizer exte
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_371 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_371 ), ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( SchemaConstants.NORMALIZERS_AT ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_372 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_372 ), ResultCodeEnum.NAMING_VIOLATION );
         }
     }
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/ObjectClassSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -27,8 +27,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -127,7 +127,7 @@ public class ObjectClassSynchronizer ext
                 String msg = I18n.err( I18n.ERR_373, entry.getDn().getName(), 
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
         }
@@ -180,7 +180,7 @@ public class ObjectClassSynchronizer ext
                 String msg = I18n.err( I18n.ERR_374, entry.getDn().getName(),
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -203,7 +203,7 @@ public class ObjectClassSynchronizer ext
         //        
         //        if ( dependees != null && dependees.size() > 0 )
         //        {
-        //            throw new LdapOperationNotSupportedException( "The objectClass with OID " + oldOc.getOid()
+        //            throw new LdapUnwillingToPerformException( "The objectClass with OID " + oldOc.getOid()
         //                + " cannot be deleted until all entities" 
         //                + " using this objectClass have also been deleted.  The following dependees exist: " 
         //                + getOids( dependees ), 
@@ -229,7 +229,7 @@ public class ObjectClassSynchronizer ext
             {
                 String msg = I18n.err( I18n.ERR_375, entry.getDn().getName(), newDn );
 
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
 
             schemaManager.unregisterObjectClass( oldOc.getOid() );
@@ -254,7 +254,7 @@ public class ObjectClassSynchronizer ext
         //        Set<ServerEntry> dependees = dao.listObjectClassDependents( oldOc );
         //        if ( dependees != null && dependees.size() > 0 )
         //        {
-        //            throw new LdapOperationNotSupportedException( "The objectClass with OID " + oldOc.getOid()
+        //            throw new LdapUnwillingToPerformException( "The objectClass with OID " + oldOc.getOid()
         //                + " cannot be deleted until all entities" 
         //                + " using this objectClass have also been deleted.  The following dependees exist: " 
         //                + getOids( dependees ), 
@@ -300,7 +300,7 @@ public class ObjectClassSynchronizer ext
         //        Set<ServerEntry> dependees = dao.listObjectClassDependents( oldAt );
         //        if ( dependees != null && dependees.size() > 0 )
         //        {s
-        //            throw new LdapOperationNotSupportedException( "The objectClass with OID " + oldAt.getOid() 
+        //            throw new LdapUnwillingToPerformException( "The objectClass with OID " + oldAt.getOid() 
         //                + " cannot be deleted until all entities" 
         //                + " using this objectClass have also been deleted.  The following dependees exist: " 
         //                + getOids( dependees ), 
@@ -333,7 +333,7 @@ public class ObjectClassSynchronizer ext
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException(
+            throw new LdapInvalidDnException(
                 "The parent dn of a objectClass should be at most 3 name components in length.",
                 ResultCodeEnum.NAMING_VIOLATION );
         }
@@ -343,13 +343,13 @@ public class ObjectClassSynchronizer ext
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_376 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_376 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( SchemaConstants.OBJECT_CLASSES_AT ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_377 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_377 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
     }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java Tue Mar 16 00:19:58 2010
@@ -38,9 +38,9 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
 import org.apache.directory.shared.ldap.entry.EntryAttribute;
 import org.apache.directory.shared.ldap.entry.Value;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.exception.LdapNamingException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.schema.AttributeType;
 import org.apache.directory.shared.ldap.schema.ObjectClass;
@@ -191,7 +191,7 @@ public class RegistrySynchronizerAdaptor
             {
                 String msg = I18n.err( I18n.ERR_81 );
                 LOG.error( msg );
-                throw new LdapInvalidNameException( msg, ResultCodeEnum.NAMING_VIOLATION );
+                throw new LdapInvalidDnException( msg, ResultCodeEnum.NAMING_VIOLATION );
             }
             
             String ouValue = ( String ) opContext.getDn().getRdn().getNormValue();
@@ -201,7 +201,7 @@ public class RegistrySynchronizerAdaptor
             {
                 String msg = I18n.err( I18n.ERR_82, VALID_OU_VALUES );
                 LOG.error( msg );
-                throw new LdapInvalidNameException( msg, ResultCodeEnum.NAMING_VIOLATION );
+                throw new LdapInvalidDnException( msg, ResultCodeEnum.NAMING_VIOLATION );
             }
             
             // this is a valid container.
@@ -211,7 +211,7 @@ public class RegistrySynchronizerAdaptor
         
         String msg = I18n.err( I18n.ERR_83, opContext.getDn() );
         LOG.error( msg );
-        throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
     
 
@@ -255,14 +255,14 @@ public class RegistrySynchronizerAdaptor
             
             if ( ! VALID_OU_VALUES.contains( ouValue ) )
             {
-                throw new LdapInvalidNameException( I18n.err( I18n.ERR_379, VALID_OU_VALUES ),
+                throw new LdapInvalidDnException( I18n.err( I18n.ERR_379, VALID_OU_VALUES ),
                     ResultCodeEnum.NAMING_VIOLATION );
             }
             
             return;
         }
 
-        throw new LdapOperationNotSupportedException( ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
     
 
@@ -304,7 +304,7 @@ public class RegistrySynchronizerAdaptor
         
         LOG.error( String.format( I18n.err( I18n.ERR_84 ), 
             opContext.getDn(), entry, opContext.getModItems() ) );
-        throw new LdapOperationNotSupportedException( ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
 
@@ -339,7 +339,7 @@ public class RegistrySynchronizerAdaptor
             return;
         }
         
-        throw new LdapOperationNotSupportedException( ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
 
@@ -368,7 +368,7 @@ public class RegistrySynchronizerAdaptor
             return;
         }
         
-        throw new LdapOperationNotSupportedException( ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
 
@@ -399,6 +399,6 @@ public class RegistrySynchronizerAdaptor
             return;
         }
         
-        throw new LdapOperationNotSupportedException( ResultCodeEnum.UNWILLING_TO_PERFORM );
+        throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -44,8 +44,8 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.entry.Modification;
 import org.apache.directory.shared.ldap.entry.ModificationOperation;
 import org.apache.directory.shared.ldap.entry.Value;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -189,7 +189,7 @@ public class SchemaSynchronizer implemen
 
         if ( !parentDn.equals( ouSchemaDN ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_380, ouSchemaDN.getName(),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_380, ouSchemaDN.getName(),
                 parentDn.toNormName() ), ResultCodeEnum.NAMING_VIOLATION );
         }
 
@@ -263,7 +263,7 @@ public class SchemaSynchronizer implemen
         {
             String msg = I18n.err( I18n.ERR_381, dependents ); 
             LOG.warn( msg );
-            throw new LdapOperationNotSupportedException(
+            throw new LdapUnwillingToPerformException(
                 msg,
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
@@ -291,7 +291,7 @@ public class SchemaSynchronizer implemen
 
         if ( ! rdnAttributeOid.equals( cnAT.getOid() ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_382, rdnAttribute ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_382, rdnAttribute ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -318,7 +318,7 @@ public class SchemaSynchronizer implemen
         Set<String> dependents = schemaManager.listDependentSchemaNames( schemaName );
         if ( ! dependents.isEmpty() )
         {
-            throw new LdapOperationNotSupportedException( 
+            throw new LdapUnwillingToPerformException( 
                 "Cannot allow a rename on " + schemaName + " schema while it has depentents.",
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
@@ -369,7 +369,7 @@ public class SchemaSynchronizer implemen
     public void moveAndRename( DN oriChildName, DN newParentName, String newRn, boolean deleteOldRn, 
         ServerEntry entry, boolean cascade ) throws NamingException
     {
-        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_383 ),
+        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_383 ),
             ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
@@ -381,7 +381,7 @@ public class SchemaSynchronizer implemen
     public void move( DN oriChildName, DN newParentName, 
         ServerEntry entry, boolean cascade ) throws NamingException
     {
-        throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_383 ),
+        throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_383 ),
             ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
@@ -575,7 +575,7 @@ public class SchemaSynchronizer implemen
             // This is not possible. We can't enable a schema which is not loaded.
             String msg = I18n.err( I18n.ERR_85, schemaName );
             LOG.error( msg );
-            throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+            throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
         
         return schemaManager.disable( schemaName );
@@ -596,7 +596,7 @@ public class SchemaSynchronizer implemen
         
         if ( ! dependents.isEmpty() )
         {
-            throw new LdapOperationNotSupportedException(
+            throw new LdapUnwillingToPerformException(
                 "Cannot disable schema with enabled dependents: " + dependents,
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
@@ -691,7 +691,7 @@ public class SchemaSynchronizer implemen
                 
                 if ( ! loaded.containsKey( dependency ) )
                 {
-                    throw new LdapOperationNotSupportedException( 
+                    throw new LdapUnwillingToPerformException( 
                         "Unwilling to perform operation on enabled schema with disabled or missing dependencies: " 
                         + dependency, ResultCodeEnum.UNWILLING_TO_PERFORM );
                 }
@@ -705,7 +705,7 @@ public class SchemaSynchronizer implemen
                 
                 if ( schemaManager.getLoadedSchema( StringTools.toLowerCase( dependency ) ) == null )
                 {
-                    throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_385, dependency ), 
+                    throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_385, dependency ), 
                         ResultCodeEnum.UNWILLING_TO_PERFORM );
                 }
             }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -27,9 +27,9 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.exception.LdapNamingException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
@@ -132,7 +132,7 @@ public class SyntaxCheckerSynchronizer e
                 String msg = I18n.err( I18n.ERR_386, entry.getDn().getName(),
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -208,7 +208,7 @@ public class SyntaxCheckerSynchronizer e
                 String msg = I18n.err( I18n.ERR_386, entry.getDn().getName(),
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -228,7 +228,7 @@ public class SyntaxCheckerSynchronizer e
 
         if ( schemaManager.getLdapSyntaxRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_389, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_389, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -263,7 +263,7 @@ public class SyntaxCheckerSynchronizer e
 
         if ( schemaManager.getLdapSyntaxRegistry().contains( oldOid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_391, oldOid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_391, oldOid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -302,7 +302,7 @@ public class SyntaxCheckerSynchronizer e
 
         if ( schemaManager.getLdapSyntaxRegistry().contains( oid ) )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_393, oid ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_393, oid ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -357,7 +357,7 @@ public class SyntaxCheckerSynchronizer e
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_396 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_396 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
@@ -365,13 +365,13 @@ public class SyntaxCheckerSynchronizer e
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_397 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_397 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( SchemaConstants.SYNTAX_CHECKERS_AT ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_372 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_372 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
     }

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-entry/src/main/java/org/apache/directory/server/core/entry/ServerEntryUtils.java (original)
+++ directory/apacheds/trunk/core-entry/src/main/java/org/apache/directory/server/core/entry/ServerEntryUtils.java Tue Mar 16 00:19:58 2010
@@ -41,7 +41,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.entry.Modification;
 import org.apache.directory.shared.ldap.entry.ModificationOperation;
 import org.apache.directory.shared.ldap.entry.Value;
-import org.apache.directory.shared.ldap.exception.LdapInvalidAttributeIdentifierException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidAttributeTypeException;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.schema.AttributeType;
 import org.apache.directory.shared.ldap.schema.SchemaManager;
@@ -467,7 +467,7 @@ public class ServerEntryUtils
                     // The attributeType does not exist in the schema.
                     // It's an error
                     String message = I18n.err( I18n.ERR_467, id );
-                    throw new LdapInvalidAttributeIdentifierException( message );
+                    throw new LdapInvalidAttributeTypeException( message );
                 }
                 else
                 {

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/authz/SearchAuthorizationIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/authz/SearchAuthorizationIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/authz/SearchAuthorizationIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/authz/SearchAuthorizationIT.java Tue Mar 16 00:19:58 2010
@@ -53,7 +53,7 @@ import javax.naming.ldap.LdapContext;
 
 import org.apache.directory.server.core.integ.AbstractLdapTestUnit;
 import org.apache.directory.server.core.integ.FrameworkRunner;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapNoPermissionException;
 import org.apache.directory.shared.ldap.name.DN;
 import org.junit.Before;
@@ -367,7 +367,7 @@ public class SearchAuthorizationIT exten
             sysRoot.lookup( base );
             fail();
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
         }
     }

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/changelog/DefaultChangeLogIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/changelog/DefaultChangeLogIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/changelog/DefaultChangeLogIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/changelog/DefaultChangeLogIT.java Tue Mar 16 00:19:58 2010
@@ -41,7 +41,7 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.factory.DefaultDirectoryServiceFactory;
 import org.apache.directory.server.core.integ.AbstractLdapTestUnit;
 import org.apache.directory.server.core.integ.FrameworkRunner;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.slf4j.Logger;
@@ -182,7 +182,7 @@ public class DefaultChangeLogIT extends 
         }
         catch ( NamingException ne )
         {
-            assertTrue( ne instanceof LdapNameNotFoundException );
+            assertTrue( ne instanceof LdapNoSuchObjectException );
         }
     }
 
@@ -402,7 +402,7 @@ public class DefaultChangeLogIT extends 
         }
         catch ( NamingException ne )
         {
-            assertTrue( ne instanceof LdapNameNotFoundException );
+            assertTrue( ne instanceof LdapNoSuchObjectException );
         }
     }
 }

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/exception/ExceptionServiceIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/exception/ExceptionServiceIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/exception/ExceptionServiceIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/exception/ExceptionServiceIT.java Tue Mar 16 00:19:58 2010
@@ -43,8 +43,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.integ.FrameworkRunner;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
 import org.apache.directory.shared.ldap.exception.LdapContextNotEmptyException;
-import org.apache.directory.shared.ldap.exception.LdapNameAlreadyBoundException;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapEntryAlreadyExistsException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.ldif.LdifUtils;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
@@ -99,7 +99,7 @@ public class ExceptionServiceIT extends 
             getSystemContext( service ).search( "ou=blah", "(objectClass=*)", ctls );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -156,7 +156,7 @@ public class ExceptionServiceIT extends 
             sysRoot.rename( "ou=users", "ou=users,ou=groups" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameAlreadyBoundException e )
+        catch ( LdapEntryAlreadyExistsException e )
         {
             assertEquals( "ou=users,ou=groups,ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.ENTRY_ALREADY_EXISTS, e.getResultCode() );
@@ -176,7 +176,7 @@ public class ExceptionServiceIT extends 
             sysRoot.removeFromEnvironment( "java.naming.ldap.deleteRDN" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameAlreadyBoundException e )
+        catch ( LdapEntryAlreadyExistsException e )
         {
             assertEquals( "ou=uzerz,ou=groups,ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.ENTRY_ALREADY_EXISTS, e.getResultCode() );
@@ -199,7 +199,7 @@ public class ExceptionServiceIT extends 
             sysRoot.rename( "ou=blah", "ou=blah,ou=groups" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -212,7 +212,7 @@ public class ExceptionServiceIT extends 
             sysRoot.removeFromEnvironment( "java.naming.ldap.deleteRDN" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -242,7 +242,7 @@ public class ExceptionServiceIT extends 
         catch ( NamingException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
     }
 
@@ -267,7 +267,7 @@ public class ExceptionServiceIT extends 
             sysRoot.rename( "ou=users", "ou=groups" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameAlreadyBoundException e )
+        catch ( LdapEntryAlreadyExistsException e )
         {
             assertEquals( "ou=groups,ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.ENTRY_ALREADY_EXISTS, e.getResultCode() );
@@ -290,7 +290,7 @@ public class ExceptionServiceIT extends 
             sysRoot.rename( "ou=blah", "ou=asdf" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=blah,ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -320,7 +320,7 @@ public class ExceptionServiceIT extends 
         catch ( NamingException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
     }
 
@@ -351,7 +351,7 @@ public class ExceptionServiceIT extends 
             sysRoot.modifyAttributes( "ou=blah", DirContext.ADD_ATTRIBUTE, attrs );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -365,7 +365,7 @@ public class ExceptionServiceIT extends 
             sysRoot.modifyAttributes( "ou=blah", mods );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -426,7 +426,7 @@ public class ExceptionServiceIT extends 
             sysRoot.lookup( "ou=blah" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -471,7 +471,7 @@ public class ExceptionServiceIT extends 
             sysRoot.list( "ou=blah" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -578,7 +578,7 @@ public class ExceptionServiceIT extends 
             createSubContext( "ou", "blah");
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameAlreadyBoundException e )
+        catch ( LdapEntryAlreadyExistsException e )
         {
             assertEquals( "ou=blah,ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.ENTRY_ALREADY_EXISTS, e.getResultCode() );
@@ -650,7 +650,7 @@ public class ExceptionServiceIT extends 
             sysRoot.destroySubcontext( "ou=blah" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );
@@ -679,7 +679,7 @@ public class ExceptionServiceIT extends 
             sysRoot.lookup( "ou=blah" );
             fail( "Execution should never get here due to exception!" );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             assertEquals( "ou=system", e.getResolvedName().toString() );
             assertEquals( ResultCodeEnum.NO_SUCH_OBJECT, e.getResultCode() );

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/DestroyContextIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/DestroyContextIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/DestroyContextIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/DestroyContextIT.java Tue Mar 16 00:19:58 2010
@@ -30,7 +30,7 @@ import javax.naming.ldap.LdapContext;
 import org.apache.directory.server.core.annotations.ApplyLdifs;
 import org.apache.directory.server.core.integ.AbstractLdapTestUnit;
 import org.apache.directory.server.core.integ.FrameworkRunner;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
@@ -88,7 +88,7 @@ public class DestroyContextIT extends Ab
         }
         catch ( NamingException e )
         {
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
 
         /*
@@ -103,7 +103,7 @@ public class DestroyContextIT extends Ab
         }
         catch ( NamingException e )
         {
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
 
         /*
@@ -118,7 +118,7 @@ public class DestroyContextIT extends Ab
         }
         catch ( NamingException e )
         {
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
 
         /*
@@ -133,7 +133,7 @@ public class DestroyContextIT extends Ab
         }
         catch ( NamingException e )
         {
-            assertTrue( e instanceof LdapNameNotFoundException );
+            assertTrue( e instanceof LdapNoSuchObjectException );
         }
     }
 

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/MixedCaseITest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/MixedCaseITest.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/MixedCaseITest.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/jndi/MixedCaseITest.java Tue Mar 16 00:19:58 2010
@@ -43,7 +43,7 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.annotations.CreatePartition;
 import org.apache.directory.server.core.integ.AbstractLdapTestUnit;
 import org.apache.directory.server.core.integ.FrameworkRunner;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.ldif.LdifUtils;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -182,7 +182,7 @@ public class MixedCaseITest extends Abst
             ctxRoot.search( dn, "(objectClass=*)", sc );
             fail( "Search should throw exception." );
         }
-        catch ( LdapNameNotFoundException e )
+        catch ( LdapNoSuchObjectException e )
         {
             // ignore
         }

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/bind/SimpleBindIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/bind/SimpleBindIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/bind/SimpleBindIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/bind/SimpleBindIT.java Tue Mar 16 00:19:58 2010
@@ -45,7 +45,7 @@ import org.apache.directory.server.core.
 import org.apache.directory.shared.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.JndiPropertyConstants;
 import org.apache.directory.shared.ldap.exception.LdapAuthenticationException;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.message.AliasDerefMode;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -382,7 +382,7 @@ public class SimpleBindIT extends Abstra
         {
             new InitialDirContext(env);
         }
-        catch ( LdapNameNotFoundException lnnfe )
+        catch ( LdapNoSuchObjectException lnnfe )
         {
             assertTrue( true );
         }

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyAddIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyAddIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyAddIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyAddIT.java Tue Mar 16 00:19:58 2010
@@ -42,7 +42,7 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.core.integ.FrameworkRunner;
 import org.apache.directory.shared.ldap.exception.LdapAttributeInUseException;
 import org.apache.directory.shared.ldap.exception.LdapInvalidAttributeValueException;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.apache.directory.shared.ldap.util.StringTools;
 import org.junit.Test;
@@ -655,7 +655,7 @@ public class ModifyAddIT extends Abstrac
     /**
      * Add an AT in an entry which does not exist
      */
-    @Test( expected = LdapNameNotFoundException.class )
+    @Test( expected = LdapNoSuchObjectException.class )
     public void testModifyAddNotExistingEntry() throws Exception
     {
         LdapContext sysRoot = getSystemContext( service );

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyDelIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyDelIT.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyDelIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/modify/ModifyDelIT.java Tue Mar 16 00:19:58 2010
@@ -40,7 +40,7 @@ import javax.naming.ldap.LdapContext;
 import org.apache.directory.server.core.annotations.ApplyLdifs;
 import org.apache.directory.server.core.integ.AbstractLdapTestUnit;
 import org.apache.directory.server.core.integ.FrameworkRunner;
-import org.apache.directory.shared.ldap.exception.LdapNameNotFoundException;
+import org.apache.directory.shared.ldap.exception.LdapNoSuchObjectException;
 import org.apache.directory.shared.ldap.exception.LdapNoSuchAttributeException;
 import org.apache.directory.shared.ldap.exception.LdapSchemaViolationException;
 import org.junit.Test;
@@ -543,7 +543,7 @@ public class ModifyDelIT extends Abstrac
     /**
      * Del an AT in an entry which does not exist
      */
-    @Test( expected = LdapNameNotFoundException.class )
+    @Test( expected = LdapNoSuchObjectException.class )
     public void testModifyDelNotExistingEntry() throws Exception
     {
         LdapContext sysRoot = getSystemContext( service );
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java Tue Mar 16 00:19:58 2010
@@ -30,8 +30,8 @@ import org.apache.directory.server.core.
 import org.apache.directory.server.i18n.I18n;
 import org.apache.directory.shared.ldap.constants.MetaSchemaConstants;
 import org.apache.directory.shared.ldap.constants.SchemaConstants;
-import org.apache.directory.shared.ldap.exception.LdapInvalidNameException;
-import org.apache.directory.shared.ldap.exception.LdapOperationNotSupportedException;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
+import org.apache.directory.shared.ldap.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.name.DN;
 import org.apache.directory.shared.ldap.name.RDN;
@@ -133,7 +133,7 @@ public class SyntaxSynchronizer extends 
                 String msg = I18n.err( I18n.ERR_399, entry.getDn().getName(),
                     StringTools.listToString( schemaManager.getErrors() ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -240,7 +240,7 @@ public class SyntaxSynchronizer extends 
                 String msg = I18n.err( I18n.ERR_400, entry.getDn().getName(), 
                     StringTools.listToString( errors ) );
                 LOG.info( msg );
-                throw new LdapOperationNotSupportedException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
+                throw new LdapUnwillingToPerformException( msg, ResultCodeEnum.UNWILLING_TO_PERFORM );
             }
         }
         else
@@ -263,7 +263,7 @@ public class SyntaxSynchronizer extends 
 
         if ( dependees.size() != 0 )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_401, oldOid,
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_401, oldOid,
                 getNames( dependees ) ), ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -303,7 +303,7 @@ public class SyntaxSynchronizer extends 
 
         if ( dependees.size() != 0 )
         {
-            throw new LdapOperationNotSupportedException( I18n.err( I18n.ERR_401, oldOid, getNames( dependees ) ),
+            throw new LdapUnwillingToPerformException( I18n.err( I18n.ERR_401, oldOid, getNames( dependees ) ),
                 ResultCodeEnum.UNWILLING_TO_PERFORM );
         }
 
@@ -349,7 +349,7 @@ public class SyntaxSynchronizer extends 
         //        
         //        if ( dependees != null && dependees.size() > 0 )
         //        {
         //            throw new LdapOperationNotSupportedException( "The syntax with OID " + oid 
         //                + " cannot be deleted until all entities" 
         //                + " using this syntax have also been deleted.  The following dependees exist: " 
         //                + getOids( dependees ), 
@@ -383,7 +383,7 @@ public class SyntaxSynchronizer extends 
     {
         if ( newParent.size() != 3 )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_402 ),
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_402 ),
                 ResultCodeEnum.NAMING_VIOLATION );
         }
 
@@ -391,12 +391,12 @@ public class SyntaxSynchronizer extends 
         if ( !schemaManager.getAttributeTypeRegistry().getOidByName( rdn.getNormType() ).equals(
             SchemaConstants.OU_AT_OID ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_403 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_403 ), ResultCodeEnum.NAMING_VIOLATION );
         }
 
         if ( !( ( String ) rdn.getNormValue() ).equalsIgnoreCase( "syntaxes" ) )
         {
-            throw new LdapInvalidNameException( I18n.err( I18n.ERR_363 ), ResultCodeEnum.NAMING_VIOLATION );
+            throw new LdapInvalidDnException( I18n.err( I18n.ERR_363 ), ResultCodeEnum.NAMING_VIOLATION );
         }
     }
 }
@@ -349,7 +349,7 @@ public class SyntaxSynchronizer extends 
         //        if ( dependees != null && dependees.size() > 0 )
         //        {
-        //            throw new LdapOperationNotSupportedException( "The syntax with OID " + oid 
+        //            throw new LdapUnwillingToPerformException( "The syntax with OID " + oid 
         //                + " cannot be deleted until all entities" 
         //                + " using this syntax have also been deleted.  The following dependees exist: " 

Modified: directory/apacheds/trunk/core-entry/src/main/java/org/apache/directory/server/core/entry/ServerEntryUtils.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-entry/src/main/java/org/apache/directory/server/core/entry/ServerEntryUtils.java?rev=923519&r1=923518&r2=923519&view=diff
==============================================================================